@@ -25,12 +25,20 @@ LOG = logging.getLogger(__name__)
 
 
 def root_app_factory(loader, global_conf, **local_conf):
-    if CONF.enable_v1_api:
-        LOG.warning('The v1 API is deprecated and is not under active '
-                    'development. You should set enable_v1_api=false '
-                    'and enable_v3_api=true in your cinder.conf file.')
-    else:
+    # To support upgrades from previous api-paste config files, we need
+    # to check for and remove any legacy references to the v1 or v2 API
+    if '/v1' in local_conf:
+        LOG.warning('The v1 API has been removed and is no longer '
+                    'available. Client applications should be '
+                    'using v3, which is currently the only supported '
+                    'version of the Block Storage API.')
         del local_conf['/v1']
-    if not CONF.enable_v2_api:
+
+    if '/v2' in local_conf:
+        LOG.warning('The v2 API has been removed and is no longer available. '
+                    'Client applications must now use the v3 API only. '
+                    'The \'enable_v2_api\' option has been removed and is '
+                    'ignored in the cinder.conf file.')
         del local_conf['/v2']
+
     return paste.urlmap.urlmap_factory(loader, global_conf, **local_conf)
