@@ -37,8 +37,6 @@ from cinder import exception
 
 # Add new constants here for each new microversion.
 
-V2_BASE_VERSION = '2.0'
-
 BASE_VERSION = '3.0'
 
 UPLOAD_IMAGE_PARAMS = '3.1'
@@ -169,6 +167,14 @@ VOLUME_TYPE_ID_IN_VOLUME_DETAIL = '3.63'
 
 ENCRYPTION_KEY_ID_IN_DETAILS = '3.64'
 
+USE_QUOTA = '3.65'
+
+SNAPSHOT_IN_USE = '3.66'
+
+PROJECT_ID_OPTIONAL_IN_URL = '3.67'
+
+SUPPORT_REIMAGE_VOLUME = '3.68'
+
 
 def get_mv_header(version):
     """Gets a formatted HTTP microversion header.
