@@ -22,8 +22,6 @@ import copy
 import re
 import unicodedata
 
-import six
-
 from cinder.common import constants
 
 
@@ -43,7 +41,7 @@ def _is_printable(char):
 
 def _get_all_chars():
     for i in range(0xFFFF):
-        yield six.unichr(i)
+        yield chr(i)
 
 
 # build a regex that matches all printable characters. This allows
@@ -67,7 +65,7 @@ def _build_regex_range(ws=True, invert=False, exclude=None):
 
     The inversion is useful when we want to generate a set of ranges
     which is everything that's not a certain class. For instance,
-    produce all all the non printable characters as a set of ranges.
+    produce all the non printable characters as a set of ranges.
     """
     if exclude is None:
         exclude = []
@@ -125,6 +123,11 @@ name = {
 }
 
 
+update_name = {
+    'type': ['string', 'null'], 'minLength': 1, 'maxLength': 255
+}
+
+
 description = {
     'type': ['string', 'null'], 'minLength': 0, 'maxLength': 255,
     'pattern': valid_description_regex,
