@@ -32,8 +32,8 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_service import loopingcall
 from oslo_utils import excutils
+from oslo_utils import secretutils
 from oslo_utils import units
-import six
 
 from cinder.backup import driver
 from cinder import exception
@@ -51,10 +51,15 @@ backup_opts = [
     cfg.StrOpt('backup_compression_algorithm',
                default='zlib',
                ignore_case=True,
-               choices=['none', 'off', 'no',
-                        'zlib', 'gzip',
-                        'bz2', 'bzip2'],
-               help='Compression algorithm ("none" to disable)'),
+               choices=[('none', 'Do not use compression'),
+                        ('off', "Same as 'none'"),
+                        ('no', "Same as 'none'"),
+                        ('zlib', 'Use the Deflate compression algorithm'),
+                        ('gzip', "Same as 'zlib'"),
+                        ('bz2', 'Use Burrows-Wheeler transform compression'),
+                        ('bzip2', "Same as 'bz2'"),
+                        ('zstd', 'Use the Zstandard compression algorithm')],
+               help="Compression algorithm for backups ('none' to disable)"),
 ]
 
 CONF = cfg.CONF
@@ -66,8 +71,7 @@ CONF.register_opts(backup_opts)
 # (https://github.com/eventlet/eventlet/issues/432) that would result in
 # failures.
 
-@six.add_metaclass(abc.ABCMeta)
-class ChunkedBackupDriver(driver.BackupDriver):
+class ChunkedBackupDriver(driver.BackupDriver, metaclass=abc.ABCMeta):
     """Abstract chunked backup driver.
 
        Implements common functionality for backup drivers that store volume
@@ -92,6 +96,9 @@ class ChunkedBackupDriver(driver.BackupDriver):
             elif algorithm.lower() in ('bz2', 'bzip2'):
                 import bz2 as compressor
                 result = compressor
+            elif algorithm.lower() == 'zstd':
+                import zstd as compressor
+                result = compressor
             else:
                 result = None
             if result:
@@ -104,10 +111,11 @@ class ChunkedBackupDriver(driver.BackupDriver):
         err = _('unsupported compression algorithm: %s') % algorithm
         raise ValueError(err)
 
-    def __init__(self, context, chunk_size_bytes, sha_block_size_bytes,
-                 backup_default_container, enable_progress_timer,
-                 db=None):
-        super(ChunkedBackupDriver, self).__init__(context, db)
+    def __init__(
+        self, context, chunk_size_bytes, sha_block_size_bytes,
+        backup_default_container, enable_progress_timer,
+    ):
+        super(ChunkedBackupDriver, self).__init__(context)
         self.chunk_size_bytes = chunk_size_bytes
         self.sha_block_size_bytes = sha_block_size_bytes
         self.backup_default_container = backup_default_container
@@ -262,8 +270,7 @@ class ChunkedBackupDriver(driver.BackupDriver):
         if extra_metadata:
             metadata['extra_metadata'] = extra_metadata
         metadata_json = json.dumps(metadata, sort_keys=True, indent=2)
-        if six.PY3:
-            metadata_json = metadata_json.encode('utf-8')
+        metadata_json = metadata_json.encode('utf-8')
         with self._get_object_writer(container, filename) as writer:
             writer.write(metadata_json)
         LOG.debug('_write_metadata finished. Metadata: %s.', metadata_json)
@@ -279,12 +286,11 @@ class ChunkedBackupDriver(driver.BackupDriver):
         sha256file['volume_id'] = volume_id
         sha256file['backup_name'] = backup['display_name']
         sha256file['backup_description'] = backup['display_description']
-        sha256file['created_at'] = six.text_type(backup['created_at'])
+        sha256file['created_at'] = str(backup['created_at'])
         sha256file['chunk_size'] = self.sha_block_size_bytes
         sha256file['sha256s'] = sha256_list
         sha256file_json = json.dumps(sha256file, sort_keys=True, indent=2)
-        if six.PY3:
-            sha256file_json = sha256file_json.encode('utf-8')
+        sha256file_json = sha256file_json.encode('utf-8')
         with self._get_object_writer(container, filename) as writer:
             writer.write(sha256file_json)
         LOG.debug('_write_sha256file finished.')
@@ -297,8 +303,7 @@ class ChunkedBackupDriver(driver.BackupDriver):
                   {'container': container, 'filename': filename})
         with self._get_object_reader(container, filename) as reader:
             metadata_json = reader.read()
-        if six.PY3:
-            metadata_json = metadata_json.decode('utf-8')
+        metadata_json = metadata_json.decode('utf-8')
         metadata = json.loads(metadata_json)
         LOG.debug('_read_metadata finished. Metadata: %s.', metadata_json)
         return metadata
@@ -311,8 +316,7 @@ class ChunkedBackupDriver(driver.BackupDriver):
                   {'container': container, 'filename': filename})
         with self._get_object_reader(container, filename) as reader:
             sha256file_json = reader.read()
-        if six.PY3:
-            sha256file_json = sha256file_json.decode('utf-8')
+        sha256file_json = sha256file_json.decode('utf-8')
         sha256file = json.loads(sha256file_json)
         LOG.debug('_read_sha256file finished.')
         return sha256file
@@ -373,7 +377,8 @@ class ChunkedBackupDriver(driver.BackupDriver):
                 container, object_name, extra_metadata=extra_metadata
         ) as writer:
             writer.write(output_data)
-        md5 = eventlet.tpool.execute(hashlib.md5, data).hexdigest()
+        md5 = eventlet.tpool.execute(
+            secretutils.md5, data, usedforsecurity=False).hexdigest()
         obj[object_name]['md5'] = md5
         LOG.debug('backup MD5 for %(object_name)s: %(md5)s',
                   {'object_name': object_name, 'md5': md5})
