@@ -84,18 +84,19 @@ class Manager(base.Base, PeriodicTasks):
 
     target = messaging.Target(version=RPC_API_VERSION)
 
-    def __init__(self,
-                 host: oslo_config.types.HostAddress = None,
-                 db_driver=None,
-                 cluster=None,
-                 **_kwargs):
+    def __init__(
+        self,
+        host: oslo_config.types.HostAddress = None,
+        cluster=None,
+        **_kwargs,
+    ):
         if not host:
             host = CONF.host
         self.host: oslo_config.types.HostAddress = host
         self.cluster = cluster
         self.additional_endpoints: list = []
         self.availability_zone = CONF.storage_availability_zone
-        super(Manager, self).__init__(db_driver)  # type: ignore
+        super().__init__()
 
     def _set_tpool_size(self, nthreads: int) -> None:
         # NOTE(geguileo): Until PR #472 is merged we have to be very careful
@@ -106,7 +107,7 @@ class Manager(base.Base, PeriodicTasks):
     def service_topic_queue(self):
         return self.cluster or self.host
 
-    def init_host(self, service_id=None, added_to_cluster=None):
+    def init_host(self, service_id, added_to_cluster=None):
         """Handle initialization if this is a standalone service.
 
         A hook point for services to execute tasks before the services are made
@@ -178,14 +179,18 @@ class SchedulerDependentManager(ThreadPoolManager):
 
     """
 
-    def __init__(self, host=None, db_driver=None, service_name='undefined',
-                 cluster=None, *args, **kwargs):
+    def __init__(
+        self,
+        host=None,
+        service_name='undefined',
+        cluster=None,
+        *args,
+        **kwargs,
+    ):
         self.last_capabilities = None
         self.service_name = service_name
         self.scheduler_rpcapi = scheduler_rpcapi.SchedulerAPI()
-        super(SchedulerDependentManager, self).__init__(host, db_driver,
-                                                        cluster=cluster,
-                                                        *args, **kwargs)
+        super().__init__(host, cluster=cluster, *args, **kwargs)
 
     def update_service_capabilities(self, capabilities):
         """Remember these capabilities to send on next periodic update."""
@@ -222,7 +227,9 @@ class SchedulerDependentManager(ThreadPoolManager):
 
 
 class CleanableManager(object):
-    def do_cleanup(self, context, cleanup_request) -> None:
+    def do_cleanup(self,
+                   context: context.RequestContext,
+                   cleanup_request: objects.CleanupRequest) -> None:
         LOG.info('Initiating service %s cleanup',
                  cleanup_request.service_id)
 
@@ -305,10 +312,10 @@ class CleanableManager(object):
 
         LOG.info('Service %s cleanup completed.', cleanup_request.service_id)
 
-    def _do_cleanup(self, ctxt, vo_resource) -> bool:
+    def _do_cleanup(self, ctxt: context.RequestContext, vo_resource) -> bool:
         return False
 
-    def init_host(self, service_id, **kwargs) -> None:
+    def init_host(self, service_id, added_to_cluster=None, **kwargs):
         ctxt = context.get_admin_context()
         self.service_id = service_id
         # TODO(geguileo): Once we don't support MySQL 5.5 anymore we can remove
