@@ -12,14 +12,14 @@
 
 from oslo_db import exception as db_exc
 from oslo_log import log as logging
+from oslo_versionedobjects import fields
 
 from cinder import db
 from cinder import exception
-from cinder.i18n import _, _LE
+from cinder.i18n import _
 from cinder import objects
 from cinder.objects import base
 from cinder.objects import fields as c_fields
-from oslo_versionedobjects import fields
 
 LOG = logging.getLogger(__name__)
 
@@ -35,6 +35,7 @@ class QualityOfServiceSpecs(base.CinderPersistentObject,
 
     OPTIONAL_FIELDS = ['volume_types']
 
+    # NOTE: When adding a field obj_make_compatible needs to be updated
     fields = {
         'id': fields.UUIDField(),
         'name': fields.StringField(),
@@ -149,7 +150,7 @@ class QualityOfServiceSpecs(base.CinderPersistentObject,
             LOG.exception(msg)
             raise exception.Invalid(msg)
         except db_exc.DBError:
-            LOG.exception(_LE('DB error occurred when creating QoS specs.'))
+            LOG.exception('DB error occurred when creating QoS specs.')
             raise exception.QoSSpecsCreateFailed(name=self.name,
                                                  qos_specs=self.specs)
         # Save ID with the object
@@ -192,9 +193,6 @@ class QualityOfServiceSpecsList(base.ObjectListBase, base.CinderObject):
     fields = {
         'objects': fields.ListOfObjectsField('QualityOfServiceSpecs'),
     }
-    child_versions = {
-        '1.0': '1.0',
-    }
 
     @classmethod
     def get_all(cls, context, *args, **kwargs):
