@@ -71,9 +71,11 @@ class SchedulerAPI(rpc.RPCAPI):
         3.8 - Addds ``valid_host_capacity`` method
         3.9 - Adds create_snapshot method
         3.10 - Adds backup_id to create_volume method.
+        3.11 - Adds manage_existing_snapshot method.
+        3.12 - Adds create_backup method.
     """
 
-    RPC_API_VERSION = '3.10'
+    RPC_API_VERSION = '3.12'
     RPC_DEFAULT_VERSION = '3.0'
     TOPIC = constants.SCHEDULER_TOPIC
     BINARY = 'cinder-scheduler'
@@ -162,6 +164,20 @@ class SchedulerAPI(rpc.RPCAPI):
         }
         return cctxt.cast(ctxt, 'manage_existing', **msg_args)
 
+    @rpc.assert_min_rpc_version('3.11')
+    def manage_existing_snapshot(self, ctxt, volume, snapshot, ref,
+                                 request_spec=None, filter_properties=None):
+        cctxt = self._get_cctxt()
+        request_spec_p = jsonutils.to_primitive(request_spec)
+        msg_args = {
+            'request_spec': request_spec_p,
+            'filter_properties': filter_properties,
+            'volume': volume,
+            'snapshot': snapshot,
+            'ref': ref,
+        }
+        return cctxt.cast(ctxt, 'manage_existing_snapshot', **msg_args)
+
     @rpc.assert_min_rpc_version('3.2')
     def extend_volume(self, ctxt, volume, new_size, reservations,
                       request_spec, filter_properties=None):
@@ -245,3 +261,9 @@ class SchedulerAPI(rpc.RPCAPI):
     def get_log_levels(self, context, service, log_request):
         cctxt = self._get_cctxt(server=service.host, version='3.7')
         return cctxt.call(context, 'get_log_levels', log_request=log_request)
+
+    @rpc.assert_min_rpc_version('3.12')
+    def create_backup(self, ctxt, backup):
+        cctxt = self._get_cctxt()
+        msg_args = {'backup': backup}
+        return cctxt.cast(ctxt, 'create_backup', **msg_args)
