@@ -13,7 +13,6 @@
 # under the License.
 
 from oslo_log import log as logging
-import six
 
 from cinder.scheduler.evaluator import evaluator
 from cinder.scheduler import weights
@@ -44,8 +43,8 @@ class GoodnessWeigher(weights.BaseHostWeigher):
         stats = self._generate_stats(host_state, weight_properties)
         LOG.debug("Checking host '%s'", stats['host_stats']['host'])
         result = self._check_goodness_function(stats)
-        LOG.debug("Goodness: %s", result)
-        LOG.debug("Done checking host '%s'", stats['host_stats']['host'])
+        LOG.debug("Goodness weight for %(host)s: %(res)s",
+                  {'res': result, 'host': stats['host_stats']['host']})
 
         return result
 
@@ -124,7 +123,7 @@ class GoodnessWeigher(weights.BaseHostWeigher):
 
         if ('goodness_function' in host_caps and
                 host_caps['goodness_function'] is not None):
-            goodness_function = six.text_type(host_caps['goodness_function'])
+            goodness_function = str(host_caps['goodness_function'])
 
         qos_specs = weight_properties.get('qos_specs', {}) or {}
 
