@@ -27,8 +27,7 @@ from cinder.api.middleware import fault
 from cinder.api.openstack import api_version_request as api_version
 from cinder.api.openstack import wsgi as os_wsgi
 from cinder.api import urlmap
-from cinder.api.v2 import limits
-from cinder.api.v2 import router
+from cinder.api.v3 import limits
 from cinder.api.v3 import router as router_v3
 from cinder.api import versions
 from cinder import context
@@ -63,8 +62,6 @@ def fake_wsgi(self, req):
 def wsgi_app(inner_app_v2=None, fake_auth=True, fake_auth_context=None,
              use_no_auth=False, ext_mgr=None,
              inner_app_v3=None):
-    if not inner_app_v2:
-        inner_app_v2 = router.APIRouter(ext_mgr)
 
     if not inner_app_v3:
         inner_app_v3 = router_v3.APIRouter(ext_mgr)
@@ -75,23 +72,16 @@ def wsgi_app(inner_app_v2=None, fake_auth=True, fake_auth_context=None,
         else:
             ctxt = context.RequestContext(fake.USER_ID, fake.PROJECT_ID,
                                           auth_token=True)
-        api_v2 = fault.FaultWrapper(auth.InjectContext(ctxt,
-                                                       inner_app_v2))
         api_v3 = fault.FaultWrapper(auth.InjectContext(ctxt,
                                                        inner_app_v3))
     elif use_no_auth:
-        api_v2 = fault.FaultWrapper(auth.NoAuthMiddleware(
-            limits.RateLimitingMiddleware(inner_app_v2)))
         api_v3 = fault.FaultWrapper(auth.NoAuthMiddleware(
             limits.RateLimitingMiddleware(inner_app_v3)))
     else:
-        api_v2 = fault.FaultWrapper(auth.AuthMiddleware(
-            limits.RateLimitingMiddleware(inner_app_v2)))
         api_v3 = fault.FaultWrapper(auth.AuthMiddleware(
             limits.RateLimitingMiddleware(inner_app_v3)))
 
     mapper = urlmap.URLMap()
-    mapper['/v2'] = api_v2
     mapper['/v3'] = api_v3
     mapper['/'] = fault.FaultWrapper(versions.VersionsController())
     return mapper
@@ -129,11 +119,13 @@ class HTTPRequest(webob.Request):
                 kwargs['base_url'] = 'http://localhost/v3'
         use_admin_context = kwargs.pop('use_admin_context', False)
         version = kwargs.pop('version', api_version._MIN_API_VERSION)
+        system_scope = kwargs.pop('system_scope', None)
         out = os_wsgi.Request.blank(*args, **kwargs)
         out.environ['cinder.context'] = FakeRequestContext(
             fake.USER_ID,
             fake.PROJECT_ID,
-            is_admin=use_admin_context)
+            is_admin=use_admin_context,
+            system_scope=system_scope)
         out.api_version_request = api_version.APIVersionRequest(version)
         return out
 
