@@ -25,12 +25,12 @@ from cinder import db
 from cinder import exception
 from cinder.objects import base as obj_base
 from cinder.scheduler import rpcapi as scheduler_rpcapi
-from cinder import test
 from cinder.tests.unit.api import fakes
 from cinder.tests.unit.api.v2 import fakes as v2_fakes
 from cinder.tests.unit.api.v2 import test_volume_metadata as v2_test
 from cinder.tests.unit import fake_constants as fake
 from cinder.tests.unit import fake_volume
+from cinder.tests.unit import test
 from cinder import volume
 from cinder.volume import api as volume_api
 
