@@ -13,11 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from cinder.common import constants
 from cinder import service
-from cinder import test
+from cinder.tests.unit import test
 
 
 class SetupProfilerTestCase(test.TestCase):
