@@ -17,7 +17,7 @@ from copy import deepcopy
 from unittest import mock
 
 from cinder import exception
-from cinder import test
+from cinder.tests.unit import test
 from cinder.tests.unit.volume.drivers.dell_emc.powermax import (
     powermax_data as tpd)
 from cinder.tests.unit.volume.drivers.dell_emc.powermax import (
@@ -36,8 +36,8 @@ class PowerMaxMigrateTest(test.TestCase):
         super(PowerMaxMigrateTest, self).setUp()
         configuration = tpfo.FakeConfiguration(
             None, 'MaskingTests', 1, 1, san_ip='1.1.1.1',
-            san_login='smc', vmax_array=self.data.array, vmax_srp='SRP_1',
-            san_password='smc', san_api_port=8443,
+            san_login='smc', powermax_array=self.data.array,
+            powermax_srp='SRP_1', san_password='smc', san_api_port=8443,
             vmax_port_groups=[self.data.port_group_name_f])
         rest.PowerMaxRest._establish_rest_session = mock.Mock(
             return_value=tpfo.FakeRequestsSession())
