@@ -1,4 +1,4 @@
-# Copyright (C) 2020, Hitachi, Ltd.
+# Copyright (C) 2020, 2021, Hitachi, Ltd.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -21,6 +21,7 @@ import requests
 
 from cinder import context as cinder_context
 from cinder.db.sqlalchemy import api as sqlalchemy_api
+from cinder import exception
 from cinder.objects import group_snapshot as obj_group_snap
 from cinder.objects import snapshot as obj_snap
 from cinder.tests.unit import fake_group
@@ -33,7 +34,7 @@ from cinder.volume import driver
 from cinder.volume.drivers.hitachi import hbsd_common
 from cinder.volume.drivers.hitachi import hbsd_iscsi
 from cinder.volume.drivers.hitachi import hbsd_rest
-from cinder.volume.drivers.hitachi import hbsd_utils
+from cinder.volume.drivers.hitachi import hbsd_rest_api
 from cinder.volume import volume_types
 from cinder.volume import volume_utils
 
@@ -63,6 +64,14 @@ DEFAULT_CONNECTOR = {
     'multipath': False,
 }
 
+DEFAULT_CONNECTOR_AIX = {
+    'os_type': 'aix',
+    'host': 'host',
+    'ip': CONFIG_MAP['my_ip'],
+    'initiator': CONFIG_MAP['host_iscsi_name'],
+    'multipath': False,
+}
+
 CTXT = cinder_context.get_admin_context()
 
 TEST_VOLUME = []
@@ -70,6 +79,7 @@ for i in range(4):
     volume = {}
     volume['id'] = '00000000-0000-0000-0000-{0:012d}'.format(i)
     volume['name'] = 'test-volume{0:d}'.format(i)
+    volume['volume_type_id'] = '00000000-0000-0000-0000-{0:012d}'.format(i)
     if i == 3:
         volume['provider_location'] = None
     else:
@@ -80,6 +90,7 @@ for i in range(4):
     else:
         volume['status'] = 'available'
     volume = fake_volume.fake_volume_obj(CTXT, **volume)
+    volume.volume_type = fake_volume.fake_volume_type_obj(CTXT)
     TEST_VOLUME.append(volume)
 
 
@@ -263,6 +274,12 @@ def _brick_get_connector_properties(multipath=False, enforce_multipath=False):
     return DEFAULT_CONNECTOR
 
 
+def _brick_get_connector_properties_aix(
+        multipath=False, enforce_multipath=False):
+    """Return a predefined connector object."""
+    return DEFAULT_CONNECTOR_AIX
+
+
 class FakeResponse():
 
     def __init__(self, status_code, data=None, headers=None):
@@ -327,6 +344,9 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
             CONFIG_MAP['port_id']]
         self.configuration.hitachi_group_create = True
         self.configuration.hitachi_group_delete = True
+        self.configuration.hitachi_copy_speed = 3
+        self.configuration.hitachi_copy_check_interval = 3
+        self.configuration.hitachi_async_copy_check_interval = 10
 
         self.configuration.san_login = CONFIG_MAP['user_id']
         self.configuration.san_password = CONFIG_MAP['user_pass']
@@ -334,9 +354,41 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
             'rest_server_ip_addr']
         self.configuration.san_api_port = CONFIG_MAP[
             'rest_server_ip_port']
+        self.configuration.hitachi_rest_disable_io_wait = True
         self.configuration.hitachi_rest_tcp_keepalive = True
         self.configuration.hitachi_discard_zero_page = True
         self.configuration.hitachi_rest_number = "0"
+        self.configuration.hitachi_lun_timeout = hbsd_rest._LUN_TIMEOUT
+        self.configuration.hitachi_lun_retry_interval = (
+            hbsd_rest._LUN_RETRY_INTERVAL)
+        self.configuration.hitachi_restore_timeout = hbsd_rest._RESTORE_TIMEOUT
+        self.configuration.hitachi_state_transition_timeout = (
+            hbsd_rest._STATE_TRANSITION_TIMEOUT)
+        self.configuration.hitachi_lock_timeout = hbsd_rest_api._LOCK_TIMEOUT
+        self.configuration.hitachi_rest_timeout = hbsd_rest_api._REST_TIMEOUT
+        self.configuration.hitachi_extend_timeout = (
+            hbsd_rest_api._EXTEND_TIMEOUT)
+        self.configuration.hitachi_exec_retry_interval = (
+            hbsd_rest_api._EXEC_RETRY_INTERVAL)
+        self.configuration.hitachi_rest_connect_timeout = (
+            hbsd_rest_api._DEFAULT_CONNECT_TIMEOUT)
+        self.configuration.hitachi_rest_job_api_response_timeout = (
+            hbsd_rest_api._JOB_API_RESPONSE_TIMEOUT)
+        self.configuration.hitachi_rest_get_api_response_timeout = (
+            hbsd_rest_api._GET_API_RESPONSE_TIMEOUT)
+        self.configuration.hitachi_rest_server_busy_timeout = (
+            hbsd_rest_api._REST_SERVER_BUSY_TIMEOUT)
+        self.configuration.hitachi_rest_keep_session_loop_interval = (
+            hbsd_rest_api._KEEP_SESSION_LOOP_INTERVAL)
+        self.configuration.hitachi_rest_another_ldev_mapped_retry_timeout = (
+            hbsd_rest_api._ANOTHER_LDEV_MAPPED_RETRY_TIMEOUT)
+        self.configuration.hitachi_rest_tcp_keepidle = (
+            hbsd_rest_api._TCP_KEEPIDLE)
+        self.configuration.hitachi_rest_tcp_keepintvl = (
+            hbsd_rest_api._TCP_KEEPINTVL)
+        self.configuration.hitachi_rest_tcp_keepcnt = (
+            hbsd_rest_api._TCP_KEEPCNT)
+        self.configuration.hitachi_host_mode_options = []
 
         self.configuration.use_chap_auth = True
         self.configuration.chap_username = CONFIG_MAP['auth_user']
@@ -450,6 +502,39 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
         self.driver.common.client.keep_session_loop.stop()
         self.driver.common.client.keep_session_loop.wait()
 
+    @mock.patch.object(requests.Session, "request")
+    @mock.patch.object(
+        volume_utils, 'brick_get_connector_properties',
+        side_effect=_brick_get_connector_properties_aix)
+    def test_do_setup_create_hg_aix(
+            self, brick_get_connector_properties, request):
+        """Normal case: The host group not exists in AIX."""
+        drv = hbsd_iscsi.HBSDISCSIDriver(
+            configuration=self.configuration)
+        self._setup_config()
+        request.side_effect = [FakeResponse(200, POST_SESSIONS_RESULT),
+                               FakeResponse(200, GET_PORTS_RESULT),
+                               FakeResponse(200, GET_PORT_RESULT),
+                               FakeResponse(200, NOTFOUND_RESULT),
+                               FakeResponse(200, NOTFOUND_RESULT),
+                               FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
+                               FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
+                               FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+        drv.do_setup(None)
+        self.assertEqual(
+            {CONFIG_MAP['port_id']:
+                '%(ip)s:%(port)s' % {
+                    'ip': CONFIG_MAP['ipv4Address'],
+                    'port': CONFIG_MAP['tcpPort']}},
+            drv.common.storage_info['portals'])
+        self.assertEqual(1, brick_get_connector_properties.call_count)
+        self.assertEqual(8, request.call_count)
+        kargs1 = request.call_args_list[6][1]
+        self.assertEqual('AIX', kargs1['json']['hostMode'])
+        # stop the Loopingcall within the do_setup treatment
+        self.driver.common.client.keep_session_loop.stop()
+        self.driver.common.client.keep_session_loop.wait()
+
     @mock.patch.object(requests.Session, "request")
     def test_extend_volume(self, request):
         request.side_effect = [FakeResponse(200, GET_LDEV_RESULT),
@@ -461,14 +546,14 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
     @mock.patch.object(driver.ISCSIDriver, "get_goodness_function")
     @mock.patch.object(driver.ISCSIDriver, "get_filter_function")
     @mock.patch.object(requests.Session, "request")
-    def test_get_volume_stats(
+    def test__update_volume_stats(
             self, request, get_filter_function, get_goodness_function):
         request.return_value = FakeResponse(200, GET_POOL_RESULT)
         get_filter_function.return_value = None
         get_goodness_function.return_value = None
-        stats = self.driver.get_volume_stats(True)
-        self.assertEqual('Hitachi', stats['vendor_name'])
-        self.assertTrue(stats["pools"][0]['multiattach'])
+        self.driver._update_volume_stats()
+        self.assertEqual('Hitachi', self.driver._stats['vendor_name'])
+        self.assertTrue(self.driver._stats["pools"][0]['multiattach'])
         self.assertEqual(1, request.call_count)
         self.assertEqual(1, get_filter_function.call_count)
         self.assertEqual(1, get_goodness_function.call_count)
@@ -533,7 +618,11 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(5, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_initialize_connection(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    def test_initialize_connection(
+            self, get_volume_type_extra_specs, request):
+        extra_specs = {"hbsd:target_ports": "CL1-A"}
+        get_volume_type_extra_specs.return_value = extra_specs
         request.side_effect = [FakeResponse(200, GET_HOST_ISCSIS_RESULT),
                                FakeResponse(200, GET_HOST_GROUP_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
@@ -553,11 +642,16 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(
             CONFIG_MAP['auth_password'], ret['data']['auth_password'])
         self.assertEqual(1, ret['data']['target_lun'])
+        self.assertEqual(1, get_volume_type_extra_specs.call_count)
         self.assertEqual(3, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_initialize_connection_shared_target(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    def test_initialize_connection_shared_target(
+            self, get_volume_type_extra_specs, request):
         """Normal case: A target shared with other systems."""
+        extra_specs = {"hbsd:target_ports": "CL1-A"}
+        get_volume_type_extra_specs.return_value = extra_specs
         request.side_effect = [FakeResponse(200, NOTFOUND_RESULT),
                                FakeResponse(200, GET_HOST_GROUPS_RESULT),
                                FakeResponse(200, GET_HOST_ISCSIS_RESULT),
@@ -578,6 +672,7 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(
             CONFIG_MAP['auth_password'], ret['data']['auth_password'])
         self.assertEqual(1, ret['data']['target_lun'])
+        self.assertEqual(1, get_volume_type_extra_specs.call_count)
         self.assertEqual(4, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
@@ -790,7 +885,7 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
 
     def test_create_group_from_src_volume_error(self):
         self.assertRaises(
-            hbsd_utils.HBSDError, self.driver.create_group_from_src,
+            exception.VolumeDriverException, self.driver.create_group_from_src,
             self.ctxt, TEST_GROUP[1], [TEST_VOLUME[1]],
             source_group=TEST_GROUP[0], source_vols=[TEST_VOLUME[3]]
         )
@@ -806,7 +901,7 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
     def test_update_group_error(self, is_group_a_cg_snapshot_type):
         is_group_a_cg_snapshot_type.return_value = True
         self.assertRaises(
-            hbsd_utils.HBSDError, self.driver.update_group,
+            exception.VolumeDriverException, self.driver.update_group,
             self.ctxt, TEST_GROUP[0], add_volumes=[TEST_VOLUME[3]],
             remove_volumes=[TEST_VOLUME[0]]
         )
@@ -876,3 +971,11 @@ class HBSDRESTISCSIDriverTest(test.TestCase):
             [{'id': TEST_SNAPSHOT[0]['id'], 'status': 'deleted'}]
         )
         self.assertTupleEqual(actual, ret)
+
+    @mock.patch.object(hbsd_iscsi.HBSDISCSIDriver, "_get_oslo_driver_opts")
+    def test_get_driver_options(self, _get_oslo_driver_opts):
+        _get_oslo_driver_opts.return_value = []
+        ret = self.driver.get_driver_options()
+        actual = (hbsd_common.COMMON_VOLUME_OPTS +
+                  hbsd_rest.REST_VOLUME_OPTS)
+        self.assertEqual(actual, ret)
