@@ -13,9 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-"""
-Tests for the Inspur InStorage volume driver.
-"""
+"""Tests for the Inspur InStorage volume driver."""
 
 import re
 
@@ -25,7 +23,6 @@ import six
 
 from cinder import exception
 from cinder import utils
-
 from cinder.volume.drivers.inspur.instorage import instorage_const
 from cinder.volume.drivers.inspur.instorage import instorage_fc
 from cinder.volume.drivers.inspur.instorage import instorage_iscsi
@@ -2171,7 +2168,7 @@ port_speed!N/A
         if peer_sys not in self._partnership_list:
             return self._errors['CMMVC5753E']
 
-        partner_state = ('fully_configured' if 'start'in kwargs
+        partner_state = ('fully_configured' if 'start' in kwargs
                          else 'fully_configured_stopped')
         self._partnership_list[peer_sys]['partnership'] = partner_state
         return('', '')
