@@ -18,12 +18,12 @@
 from unittest import mock
 
 from eventlet import greenthread
-from oslo_utils import importutils
 import six
 
 from cinder import context
+import cinder.db
 from cinder import exception
-from cinder import test
+from cinder.tests.unit import test
 from cinder.tests.unit import utils as testutils
 from cinder.tests.unit.volume.drivers.inspur.instorage import fakes
 from cinder.volume import configuration as conf
@@ -57,8 +57,7 @@ class InStorageMCSISCSIDriverTestCase(test.TestCase):
 
         self._reset_flags()
         self.ctxt = context.get_admin_context()
-        db_driver = self.iscsi_driver.configuration.db_driver
-        self.db = importutils.import_module(db_driver)
+        self.db = cinder.db
         self.iscsi_driver.db = self.db
         self.iscsi_driver.do_setup(None)
         self.iscsi_driver.check_for_setup_error()
