@@ -21,7 +21,7 @@ from oslo_utils import units
 
 from cinder import context
 from cinder import db
-from cinder import test
+from cinder.tests.unit import test
 from cinder.volume import configuration as conf
 from cinder.volume.drivers.nexenta import iscsi
 from cinder.volume.drivers.nexenta import jsonrpc
@@ -616,7 +616,9 @@ class TestNexentaNfsDriver(test.TestCase):
         self.nms_mock.snapshot.destroy.assert_called_with(
             'stack/share/volume-1@snapshot1', '')
 
-    def test_delete_volume(self):
+    @mock.patch('os_brick.remotefs.remotefs.'
+                'RemoteFsClient._read_mounts')
+    def test_delete_volume(self, list_mount_points):
         self.drv.share2nms = {self.TEST_EXPORT1: self.nms_mock}
         self._create_volume_db_entry()
 
@@ -633,6 +635,7 @@ class TestNexentaNfsDriver(test.TestCase):
         })
         self.nms_mock.folder.destroy.assert_called_with(
             'stack/share/volume-1', '-r')
+        list_mount_points.assert_called_once()
 
         # Check that exception not raised if folder does not exist on
         # NexentaStor appliance.
