@@ -17,7 +17,7 @@ import fixtures
 
 from cinder import exception
 from cinder.i18n import _
-from cinder import test
+from cinder.tests.unit import test
 from cinder.tests.unit.volume import test_driver
 
 
@@ -120,7 +120,7 @@ class RSDClientTestCase(test.TestCase):
         rsd_client = rsd_driver.RSDClient.initialize(MOCK_URL, MOCK_USER,
                                                      MOCK_PASSWORD,
                                                      verify=True)
-        self.assertTrue(isinstance(rsd_client, rsd_driver.RSDClient))
+        self.assertIsInstance(rsd_client, rsd_driver.RSDClient)
 
     def test_initialize_rsd_api_incorrect_version(self):
         self.mock_rsd_lib._rsd_api_version = "2.3.0"
@@ -134,7 +134,7 @@ class RSDClientTestCase(test.TestCase):
         rsd_client = rsd_driver.RSDClient.initialize(MOCK_URL, MOCK_USER,
                                                      MOCK_PASSWORD,
                                                      verify=True)
-        self.assertTrue(isinstance(rsd_client, rsd_driver.RSDClient))
+        self.assertIsInstance(rsd_client, rsd_driver.RSDClient)
 
     def test_initialize_rsd_lib_incorrect_version(self):
         self.mock_rsd_lib._redfish_version = "1.0.0"
@@ -148,7 +148,7 @@ class RSDClientTestCase(test.TestCase):
         rsd_client = rsd_driver.RSDClient.initialize(MOCK_URL, MOCK_USER,
                                                      MOCK_PASSWORD,
                                                      verify=True)
-        self.assertTrue(isinstance(rsd_client, rsd_driver.RSDClient))
+        self.assertIsInstance(rsd_client, rsd_driver.RSDClient)
 
     def test_initialize_invalid_credentials(self):
         self.mock_rsd_lib_factory.side_effect = (
@@ -1014,14 +1014,6 @@ class RSDDriverTestCase(test_driver.BaseDriverTestCase):
         self.rsd_client.delete_vol_or_snap.assert_called()
         self.assertEqual(2, self.rsd_client.delete_vol_or_snap.call_count)
 
-    def test_get_volume_stats(self):
-        ret_tuple = (25.0, 60.0, 35.0, 6)
-        self.rsd_client.get_stats = mock.Mock(return_value=ret_tuple)
-
-        stats = self.volume.driver.get_volume_stats()
-
-        self.assertEqual({}, stats)
-
     def test_get_volume_stats_refresh(self):
         ret_tuple = (25.0, 60.0, 35.0, 6)
         self.rsd_client.get_stats = mock.Mock(return_value=ret_tuple)
