@@ -19,19 +19,14 @@ from taskflow.types import failure as ft
 
 from cinder import context
 from cinder import exception
-from cinder import test
 from cinder.tests.unit import fake_constants as fakes
 from cinder.tests.unit import fake_volume
+from cinder.tests.unit import test
 from cinder.tests.unit.volume.flows import fake_volume_api
 from cinder.volume.flows.api import manage_existing
 from cinder.volume.flows import common as flow_common
 from cinder.volume.flows.manager import manage_existing as manager
 
-if hasattr(inspect, 'getfullargspec'):
-    getargspec = inspect.getfullargspec
-else:
-    getargspec = inspect.getargspec
-
 
 class ManageVolumeFlowTestCase(test.TestCase):
 
@@ -270,10 +265,10 @@ class ManageVolumeFlowTestCase(test.TestCase):
                 for p in task.default_provides:
                     provides.add(p)
 
-            execute_args = getargspec(task.execute)[0]
+            execute_args = inspect.getfullargspec(task.execute)[0]
             execute_args = [x for x in execute_args if x not in provides]
             [self.assertIn(arg, param_names) for arg in execute_args]
 
-            revert_args = getargspec(task.revert)[0]
+            revert_args = inspect.getfullargspec(task.revert)[0]
             revert_args = [x for x in revert_args if x not in revert_provides]
             [self.assertIn(arg, param_names) for arg in revert_args]
