@@ -294,6 +294,7 @@ class CommonAdapter(object):
             "compression_support": True,
             "multiattach": True,
             "consistent_group_snapshot_enabled": True,
+            "sparse_copy_volume": True,
         }
         backend_stats = self.client.get_metrics()
         backend_total_capacity = utils.bytes_to_gib(
@@ -1056,6 +1057,7 @@ class FibreChannelAdapter(CommonAdapter):
                 "target_discovered": False,
                 "target_lun": volume_lun,
                 "target_wwn": target_wwns,
+                "discard": True,
             }
         }
 
