@@ -77,6 +77,11 @@ common_opts = [
                 default=[],
                 help='Comma separated Fault Domain IPs to be excluded '
                      'from iSCSI returns.'),
+    cfg.ListOpt('included_domain_ips',
+                item_type=types.IPAddress(),
+                default=[],
+                help='Comma separated Fault Domain IPs to be included '
+                     'from iSCSI returns.'),
     cfg.StrOpt('dell_server_os',
                default='Red Hat Linux 6.x',
                help='Server OS type to use when creating a new server on the '
@@ -702,21 +707,6 @@ class SCCommonDriver(driver.ManageableVD,
         msg = _('Unable to extend volume %s') % volume_name
         raise exception.VolumeBackendAPIException(data=msg)
 
-    def get_volume_stats(self, refresh=False):
-        """Get volume status.
-
-        If 'refresh' is True, run update the stats first.
-        """
-        if refresh:
-            self._update_volume_stats()
-
-        # Take this opportunity to report our failover state.
-        if self.failed_over:
-            LOG.debug('%(source)s has been failed over to %(dest)s',
-                      {'source': self.backend_name,
-                       'dest': self.active_backend_id})
-        return self._stats
-
     def _update_volume_stats(self):
         """Retrieve stats info from volume group."""
         with self._client.open_connection() as api:
@@ -765,6 +755,12 @@ class SCCommonDriver(driver.ManageableVD,
                       {'total': data['total_capacity_gb'],
                        'free': data['free_capacity_gb']})
 
+        # Take this opportunity to report our failover state.
+        if self.failed_over:
+            LOG.debug('%(source)s has been failed over to %(dest)s',
+                      {'source': self.backend_name,
+                       'dest': self.active_backend_id})
+
     def update_migrated_volume(self, ctxt, volume, new_volume,
                                original_volume_status):
         """Return model update for migrated volume.
