@@ -84,14 +84,16 @@ class VNXDriver(driver.ManageableVD,
           13.0.0 - Fix bug https://bugs.launchpad.net/cinder/+bug/1817385 to
                    make sure sg can be created again after it was destroyed
                    under `destroy_empty_stroage_group` setting to `True`
-          13.0.1 - Fix bug 1794646: failed to delete LUNs from backend due to
+          14.0.0 - Fix bug 1794646: failed to delete LUNs from backend due to
                    the temporary snapshots on them wasn't deleted.
+          14.0.1 - Fix bug 1796825, add an option to set default value for
+                   `async_migrate`.
     """
 
-    VERSION = '13.00.01'
+    VERSION = '14.00.01'
     VENDOR = 'Dell EMC'
     # ThirdPartySystems wiki page
-    CI_WIKI_NAME = "EMC_VNX_CI"
+    CI_WIKI_NAME = "DellEMC_VNX_CI"
 
     def __init__(self, *args, **kwargs):
         super(VNXDriver, self).__init__(*args, **kwargs)
@@ -242,17 +244,7 @@ class VNXDriver(driver.ManageableVD,
         zm_utils.remove_fc_zone(conn_info)
         return conn_info
 
-    def get_volume_stats(self, refresh=False):
-        """Get volume stats.
-
-        :param refresh: True to get updated data
-        """
-        if refresh:
-            self.update_volume_stats()
-
-        return self._stats
-
-    def update_volume_stats(self):
+    def _update_volume_stats(self):
         """Retrieve stats info from volume group."""
         LOG.debug("Updating volume stats.")
         self._stats = self.adapter.update_volume_stats()
