@@ -117,10 +117,11 @@ class InfiniboxVolumeDriver(san.SanISCSIDriver):
         1.5 - added support for volume compression
         1.6 - added support for volume multi-attach
         1.7 - fixed iSCSI to return all portals
+        1.7.1 - added support for TLS/SSL communication
 
     """
 
-    VERSION = '1.7'
+    VERSION = '1.7.1'
 
     # ThirdPartySystems wiki page
     CI_WIKI_NAME = "INFINIDAT_CI"
@@ -137,11 +138,14 @@ class InfiniboxVolumeDriver(san.SanISCSIDriver):
             'chap_username', 'chap_password', 'san_thin_provision',
             'use_multipath_for_image_xfer', 'enforce_multipath_for_image_xfer',
             'num_volume_device_scan_tries', 'volume_dd_blocksize',
+            'driver_use_ssl', 'suppress_requests_ssl_warnings',
             'max_over_subscription_ratio')
         return infinidat_opts + additional_opts
 
-    def _setup_and_get_system_object(self, management_address, auth):
-        system = infinisdk.InfiniBox(management_address, auth=auth)
+    def _setup_and_get_system_object(self, management_address, auth,
+                                     use_ssl=False):
+        system = infinisdk.InfiniBox(management_address, auth=auth,
+                                     use_ssl=use_ssl)
         system.api.add_auto_retry(
             lambda e: isinstance(
                 e, infinisdk.core.exceptions.APITransportFailure) and
@@ -158,9 +162,10 @@ class InfiniboxVolumeDriver(san.SanISCSIDriver):
             raise exception.VolumeDriverException(message=msg)
         auth = (self.configuration.san_login,
                 self.configuration.san_password)
+        use_ssl = self.configuration.driver_use_ssl
         self.management_address = self.configuration.san_ip
-        self._system = (
-            self._setup_and_get_system_object(self.management_address, auth))
+        self._system = self._setup_and_get_system_object(
+            self.management_address, auth, use_ssl=use_ssl)
         backend_name = self.configuration.safe_get('volume_backend_name')
         self._backend_name = backend_name or self.__class__.__name__
         self._volume_stats = None
