@@ -134,7 +134,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             'volume_dd_blocksize', 'unique_fqdn_network')
         return kaminario_opts + additional_opts
 
-    @utils.trace
+    @volume_utils.trace
     def check_for_setup_error(self):
         if krest is None:
             msg = _("Unable to import 'krest' python module.")
@@ -183,12 +183,12 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
                     raise exception.InvalidInput(reason=msg)
             self.replica = Replication(replica[0])
 
-    @utils.trace
+    @volume_utils.trace
     def do_setup(self, context):
         super(KaminarioCinderDriver, self).do_setup(context)
         self._check_ops()
 
-    @utils.trace
+    @volume_utils.trace
     def create_volume(self, volume):
         """Volume creation in K2 needs a volume group.
 
@@ -222,7 +222,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
         if self._get_is_replica(volume.volume_type) and self.replica:
             self._create_volume_replica(volume, vg, vol, self.replica.rpo)
 
-    @utils.trace
+    @volume_utils.trace
     def _create_volume_replica(self, volume, vg, vol, rpo):
         """Volume replica creation in K2 needs session and remote volume.
 
@@ -280,7 +280,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             self._delete_by_ref(self.client, "volume_groups", vg.name, "vg")
             raise KaminarioCinderDriverException(reason=ex)
 
-    @utils.trace
+    @volume_utils.trace
     def _create_failover_volume_replica(self, volume, vg_name, vol_name):
         """Volume replica creation in K2 needs session and remote volume.
 
@@ -335,14 +335,14 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             self._delete_by_ref(self.client, "volume_groups", vg_name, "vg")
             raise KaminarioCinderDriverException(reason=ex)
 
-    @utils.trace
+    @volume_utils.trace
     def _delete_by_ref(self, device, url, name, msg):
         rs = device.search(url, name=name)
         for result in rs.hits:
             result.delete()
             LOG.debug("Deleting %(msg)s: %(name)s", {'msg': msg, 'name': name})
 
-    @utils.trace
+    @volume_utils.trace
     def _failover_volume(self, volume):
         """Promoting a secondary volume to primary volume."""
         session_name = self.get_session_name(volume.id)
@@ -355,7 +355,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             LOG.debug("The target session: %s state is "
                       "changed to failed_over ", rsession_name)
 
-    @utils.trace
+    @volume_utils.trace
     def failover_host(self, context, volumes, secondary_id=None, groups=None):
         """Failover to replication target."""
         volume_updates = []
@@ -509,7 +509,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             back_end_ip = self.replica.backend_id
         return back_end_ip, volume_updates, []
 
-    @utils.trace
+    @volume_utils.trace
     def _create_volume_replica_user_snap(self, k2, sess):
         snap = k2.new("snapshots")
         snap.is_application_consistent = "False"
@@ -520,10 +520,10 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
     def _is_user_snap_sync_finished(self):
         # waiting for user snapshot to be synced
         while len(self.snap_updates) > 0:
-            for l in self.snap_updates:
-                sess = l.get('tgt_ssn')
-                gno = l.get('gno')
-                stime = l.get('stime')
+            for update in self.snap_updates:
+                sess = update.get('tgt_ssn')
+                gno = update.get('gno')
+                stime = update.get('stime')
                 sess.refresh()
                 if (sess.generation_number == gno and
                    sess.current_snapshot_progress == 100
@@ -535,10 +535,10 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
                         self.snap_updates.append({'tgt_ssn': sess,
                                                   'gno': gen_no,
                                                   'stime': time.time()})
-                    self.snap_updates.remove(l)
+                    self.snap_updates.remove(update)
                 eventlet.sleep(1)
 
-    @utils.trace
+    @volume_utils.trace
     def create_volume_from_snapshot(self, volume, snapshot):
         """Create volume from snapshot.
 
@@ -553,7 +553,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
         vol_name = self.get_volume_name(volume.id)
         cview = src_attach_info = dest_attach_info = None
         rpolicy = self.get_policy()
-        properties = utils.brick_get_connector_properties()
+        properties = volume_utils.brick_get_connector_properties()
         LOG.debug("Searching for snapshot: %s in K2.", snap_name)
         snap_rs = self.client.search("snapshots", short_name=snap_name)
         if hasattr(snap_rs, 'hits') and snap_rs.total != 0:
@@ -603,7 +603,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
                           "failed", {"vol": vol_name, "view": view_name})
             raise KaminarioCinderDriverException(reason=ex)
 
-    @utils.trace
+    @volume_utils.trace
     def create_cloned_volume(self, volume, src_vref):
         """Create a clone from source volume.
 
@@ -624,7 +624,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             LOG.error(msg)
             raise KaminarioCinderDriverException(reason=msg)
         try:
-            properties = utils.brick_get_connector_properties()
+            properties = volume_utils.brick_get_connector_properties()
             conn = self.initialize_connection(src_vref, properties)
             src_attach_info = self._connect_device(conn)
             self.create_volume(volume)
@@ -648,7 +648,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             LOG.exception("Create a clone: %s failed.", clone_name)
             raise KaminarioCinderDriverException(reason=ex)
 
-    @utils.trace
+    @volume_utils.trace
     def delete_volume(self, volume):
         """Volume in K2 exists in a volume group.
 
@@ -673,7 +673,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             LOG.exception("Deletion of volume %s failed.", vol_name)
             raise KaminarioCinderDriverException(reason=ex)
 
-    @utils.trace
+    @volume_utils.trace
     def _delete_volume_replica(self, volume, vg_name, vol_name):
         rvg_name = self.get_rep_name(vg_name)
         rvol_name = self.get_rep_name(vol_name)
@@ -707,7 +707,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
         self._delete_by_ref(self.target, "volume_groups",
                             rvg_name, "remote vg")
 
-    @utils.trace
+    @volume_utils.trace
     def _delete_failover_volume_replica(self, volume, vg_name, vol_name):
         rvg_name = self.get_rep_name(vg_name)
         rvol_name = self.get_rep_name(vol_name)
@@ -732,7 +732,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             obj.refresh()
             eventlet.sleep(1)
 
-    @utils.trace
+    @volume_utils.trace
     def get_volume_stats(self, refresh=False):
         if refresh:
             self.update_volume_stats()
@@ -754,7 +754,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
     def remove_export(self, context, volume):
         pass
 
-    @utils.trace
+    @volume_utils.trace
     def create_snapshot(self, snapshot):
         """Create a snapshot from a volume_group."""
         vg_name = self.get_volume_group_name(snapshot.volume_id)
@@ -772,7 +772,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             LOG.exception("Creation of snapshot: %s failed.", snap_name)
             raise KaminarioCinderDriverException(reason=ex)
 
-    @utils.trace
+    @volume_utils.trace
     def delete_snapshot(self, snapshot):
         """Delete a snapshot."""
         snap_name = self.get_snap_name(snapshot.id)
@@ -785,7 +785,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
             LOG.exception("Deletion of snapshot: %s failed.", snap_name)
             raise KaminarioCinderDriverException(reason=ex)
 
-    @utils.trace
+    @volume_utils.trace
     def extend_volume(self, volume, new_size):
         """Extend volume."""
         vol_name = self.get_volume_name(volume.id)
@@ -867,7 +867,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
         """Return the corresponding replication names."""
         return "r{0}".format(name)
 
-    @utils.trace
+    @volume_utils.trace
     def _delete_host_by_name(self, name):
         """Deleting host by name."""
         host_rs = self.client.search("hosts", name=name)
@@ -911,7 +911,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
     def initialize_connection(self, volume, connector):
         pass
 
-    @utils.trace
+    @volume_utils.trace
     def terminate_connection(self, volume, connector):
         """Terminate connection of volume from host."""
         # Get volume object
@@ -947,7 +947,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
         else:
             LOG.warning("Host: %s not found on K2.", host_name)
 
-    @utils.trace
+    @volume_utils.trace
     def k2_initialize_connection(self, volume, connector):
         # Get volume object.
         if type(volume).__name__ != 'RestObject':
@@ -1006,7 +1006,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
                 return True
         return False
 
-    @utils.trace
+    @volume_utils.trace
     def manage_existing(self, volume, existing_ref):
         vol_name = existing_ref['source-name']
         new_name = self.get_volume_name(volume.id)
@@ -1057,7 +1057,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
                     vg.save()
             raise
 
-    @utils.trace
+    @volume_utils.trace
     def manage_existing_get_size(self, volume, existing_ref):
         vol_name = existing_ref['source-name']
         v_rs = self.client.search("volumes", name=vol_name)
@@ -1070,7 +1070,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
                 existing_ref=existing_ref,
                 reason=_('Unable to get size of manage volume.'))
 
-    @utils.trace
+    @volume_utils.trace
     def after_volume_copy(self, ctxt, volume, new_volume, remote=None):
         self.delete_volume(volume)
         vg_name_old = self.get_volume_group_name(volume.id)
@@ -1084,7 +1084,7 @@ class KaminarioCinderDriver(cinder.volume.driver.ISCSIDriver):
         vol_new.name = vol_name_old
         vol_new.save()
 
-    @utils.trace
+    @volume_utils.trace
     def retype(self, ctxt, volume, new_type, diff, host):
         old_type = volume.get('volume_type')
         vg_name = self.get_volume_group_name(volume.id)
