@@ -26,6 +26,7 @@ from cinder.i18n import _
 from cinder import utils
 from cinder.volume.drivers.netapp.dataontap.client import api as netapp_api
 from cinder.volume.drivers.netapp import utils as na_utils
+from cinder.volume import volume_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -33,7 +34,7 @@ DELETED_PREFIX = 'deleted_cinder_'
 MAX_SIZE_FOR_A_LUN = '17555678822400'
 
 
-@six.add_metaclass(utils.TraceWrapperMetaclass)
+@six.add_metaclass(volume_utils.TraceWrapperMetaclass)
 class Client(object):
 
     def __init__(self, **kwargs):
@@ -105,8 +106,10 @@ class Client(object):
             raise ValueError('Expects NaElement')
 
     def create_lun(self, volume_name, lun_name, size, metadata,
-                   qos_policy_group_name=None):
+                   qos_policy_group_name=None,
+                   qos_policy_group_is_adaptive=False):
         """Issues API request for creating LUN on volume."""
+        self._validate_qos_policy_group(qos_policy_group_is_adaptive)
 
         path = '/vol/%s/%s' % (volume_name, lun_name)
         space_reservation = metadata['SpaceReserved']
@@ -133,7 +136,12 @@ class Client(object):
             'lun-create-by-size',
             **params)
         if qos_policy_group_name:
-            lun_create.add_new_child('qos-policy-group', qos_policy_group_name)
+            if qos_policy_group_is_adaptive:
+                lun_create.add_new_child(
+                    'qos-adaptive-policy-group', qos_policy_group_name)
+            else:
+                lun_create.add_new_child(
+                    'qos-policy-group', qos_policy_group_name)
 
         try:
             self.connection.invoke_successfully(lun_create, True)
@@ -307,6 +315,10 @@ class Client(object):
         """Get igroups exactly matching a set of initiators."""
         raise NotImplementedError()
 
+    def _validate_qos_policy_group(self, is_adaptive, spec=None, is_nfs=False):
+        """Raises an exception if the backend doesn't support the QoS spec."""
+        raise NotImplementedError()
+
     def _has_luns_mapped_to_initiator(self, initiator):
         """Checks whether any LUNs are mapped to the given initiator."""
         lun_list_api = netapp_api.NaElement('lun-initiator-list-map-info')
