@@ -95,7 +95,7 @@ class WindowsSmbfsDriver(remotefs_drv.RevertToSnapshotMixin,
     _DISK_FORMAT_VHDX = 'vhdx'
 
     # ThirdPartySystems wiki page
-    CI_WIKI_NAME = "Microsoft_iSCSI_CI"
+    CI_WIKI_NAME = "Cloudbase_Cinder_SMB3_CI"
 
     _MINIMUM_QEMU_IMG_VERSION = '1.6'
 
@@ -335,7 +335,8 @@ class WindowsSmbfsDriver(remotefs_drv.RevertToSnapshotMixin,
         vhd_type = self._get_vhd_type()
 
         self._vhdutils.create_vhd(volume_path, vhd_type,
-                                  max_internal_size=volume_size_bytes)
+                                  max_internal_size=volume_size_bytes,
+                                  guid=volume.id)
 
     def _ensure_share_mounted(self, smbfs_share):
         mnt_flags = None
@@ -602,13 +603,23 @@ class WindowsSmbfsDriver(remotefs_drv.RevertToSnapshotMixin,
             self.configuration.volume_dd_blocksize,
             volume_subformat)
 
-        self._vhdutils.resize_vhd(self.local_path(volume),
+        volume_path = self.local_path(volume)
+        self._vhdutils.set_vhd_guid(volume_path, volume.id)
+        self._vhdutils.resize_vhd(volume_path,
                                   volume.size * units.Gi,
                                   is_file_max_size=False)
 
-    def _copy_volume_from_snapshot(self, snapshot, volume, volume_size):
+    def _copy_volume_from_snapshot(self, snapshot, volume, volume_size,
+                                   src_encryption_key_id=None,
+                                   new_encryption_key_id=None):
         """Copy data from snapshot to destination volume."""
 
+        if new_encryption_key_id:
+            msg = _("Encryption key %s was requested. Volume "
+                    "encryption is not currently supported.")
+            raise exception.NotSupportedOperation(
+                message=msg % new_encryption_key_id)
+
         LOG.debug("snapshot: %(snap)s, volume: %(vol)s, "
                   "volume_size: %(size)s",
                   {'snap': snapshot.id,
@@ -629,6 +640,7 @@ class WindowsSmbfsDriver(remotefs_drv.RevertToSnapshotMixin,
         self._vhdutils.convert_vhd(snapshot_path,
                                    volume_path,
                                    vhd_type=vhd_type)
+        self._vhdutils.set_vhd_guid(volume_path, volume.id)
         self._vhdutils.resize_vhd(volume_path, volume_size * units.Gi,
                                   is_file_max_size=False)
 
@@ -669,6 +681,17 @@ class WindowsSmbfsDriver(remotefs_drv.RevertToSnapshotMixin,
         return os.path.join(volume_location['mountpoint'],
                             volume.name + ".%s" % fmt).lower()
 
+    def manage_existing(self, volume, existing_ref):
+        model_update = super(WindowsSmbfsDriver, self).manage_existing(
+            volume, existing_ref)
+
+        volume.provider_location = model_update['provider_location']
+        volume_path = self.local_path(volume)
+
+        self._vhdutils.set_vhd_guid(volume_path, volume.id)
+
+        return model_update
+
     def _set_rw_permissions(self, path):
         # The SMBFS driver does not manage file permissions. We chose
         # to let this up to the deployer.
