@@ -19,7 +19,7 @@ from cinder import exception
 from cinder.i18n import _
 from cinder import utils
 from cinder.volume.targets import driver
-from cinder.volume import utils as vutils
+from cinder.volume import volume_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -35,10 +35,8 @@ class ISCSITarget(driver.Target):
 
     def __init__(self, *args, **kwargs):
         super(ISCSITarget, self).__init__(*args, **kwargs)
-        self.iscsi_target_prefix = \
-            self.configuration.safe_get('target_prefix')
-        self.iscsi_protocol = \
-            self.configuration.safe_get('target_protocol')
+        self.iscsi_target_prefix = self.configuration.safe_get('target_prefix')
+        self.iscsi_protocol = self.configuration.safe_get('target_protocol')
         self.protocol = 'iSCSI'
         self.volumes_dir = self.configuration.safe_get('volumes_dir')
 
@@ -105,16 +103,7 @@ class ISCSITarget(driver.Target):
         try:
             lun = int(results[2])
         except (IndexError, ValueError):
-            # NOTE(jdg): The following is carried over from the existing
-            # code.  The trick here is that different targets use different
-            # default lun numbers, the base driver with tgtadm uses 1
-            # others like LIO use 0.
-            if (self.configuration.volume_driver ==
-                    'cinder.volume.drivers.lvm.ThinLVMVolumeDriver' and
-                    self.configuration.target_helper == 'tgtadm'):
-                lun = 1
-            else:
-                lun = 0
+            lun = 0
 
         if nr_portals > 1 or multipath:
             properties['target_portals'] = portals
@@ -194,8 +183,8 @@ class ISCSITarget(driver.Target):
         # if DNE no big deal, we'll just create it
         chap_auth = self._get_target_chap_auth(context, volume)
         if not chap_auth:
-            chap_auth = (vutils.generate_username(),
-                         vutils.generate_password())
+            chap_auth = (volume_utils.generate_username(),
+                         volume_utils.generate_password())
 
         # Get portals ips and port
         portals_config = self._get_portals_config()
@@ -302,7 +291,8 @@ class ISCSITarget(driver.Target):
     def _iscsi_location(self, ip, target, iqn, lun=None, ip_secondary=None):
         ip_secondary = ip_secondary or []
         port = self.configuration.target_port
-        portals = map(lambda x: "%s:%s" % (vutils.sanitize_host(x), port),
+        portals = map(lambda x: "%s:%s" % (volume_utils.sanitize_host(x),
+                                           port),
                       [ip] + ip_secondary)
         return ("%(portals)s,%(target)s %(iqn)s %(lun)s"
                 % ({'portals': ";".join(portals),
