@@ -19,6 +19,7 @@
 
 """Built-in volume type properties."""
 
+import typing as ty
 
 from oslo_config import cfg
 from oslo_db import exception as db_exc
@@ -116,17 +117,28 @@ def destroy(context, id):
     if id is None:
         msg = _("id cannot be None")
         raise exception.InvalidVolumeType(reason=msg)
-    elevated = context if context.is_admin else context.elevated()
+
+    projects_with_default_type = db.get_all_projects_with_default_type(
+        context.elevated(), id)
+    if len(projects_with_default_type) > 0:
+        # don't allow delete if the type requested is a project default
+        project_list = [p.project_id for p in projects_with_default_type]
+        LOG.exception('Default type with %(volume_type_id)s is associated '
+                      'with projects %(projects)s',
+                      {'volume_type_id': id,
+                       'projects': project_list})
+        raise exception.VolumeTypeDefaultDeletionError(volume_type_id=id)
 
     # Default type *must* be set in order to delete any volume type.
     # If the default isn't set, the following call will raise
     # VolumeTypeDefaultMisconfiguredError exception which will error out the
     # delete operation.
     default_type = get_default_volume_type()
-    # don't allow delete if the type requested is the default type
+    # don't allow delete if the type requested is the conf default type
     if id == default_type.get('id'):
         raise exception.VolumeTypeDefaultDeletionError(volume_type_id=id)
 
+    elevated = context if context.is_admin else context.elevated()
     return db.volume_type_destroy(elevated, id)
 
 
@@ -189,12 +201,18 @@ def get_volume_type_by_name(context, name):
     return db.volume_type_get_by_name(context, name)
 
 
-def get_default_volume_type():
+def get_default_volume_type(contxt=None):
     """Get the default volume type.
 
     :raises VolumeTypeDefaultMisconfiguredError: when the configured default
                                                  is not found
     """
+
+    if contxt:
+        project_default = db.project_default_volume_type_get(
+            contxt, contxt.project_id)
+        if project_default:
+            return get_volume_type(contxt, project_default.volume_type_id)
     name = CONF.default_volume_type
     ctxt = context.get_admin_context()
     vol_type = {}
@@ -294,7 +312,8 @@ def remove_volume_type_access(context, volume_type_id, project_id):
                                           'access.remove')
 
 
-def is_encrypted(context, volume_type_id):
+def is_encrypted(context: context.RequestContext,
+                 volume_type_id: str) -> bool:
     return get_volume_type_encryption(context, volume_type_id) is not None
 
 
@@ -314,7 +333,9 @@ def get_volume_type_qos_specs(volume_type_id):
     return res
 
 
-def volume_types_diff(context, vol_type_id1, vol_type_id2):
+def volume_types_diff(context: context.RequestContext,
+                      vol_type_id1,
+                      vol_type_id2) -> ty.Tuple[dict, bool]:
     """Returns a 'diff' of two volume types and whether they are equal.
 
     Returns a tuple of (diff, equal), where 'equal' is a boolean indicating
@@ -354,7 +375,8 @@ def volume_types_diff(context, vol_type_id1, vol_type_id2):
                 encryption.pop(param, None)
         return encryption
 
-    def _dict_diff(dict1, dict2):
+    def _dict_diff(dict1: ty.Optional[dict],
+                   dict2: ty.Optional[dict]) -> ty.Tuple[dict, bool]:
         res = {}
         equal = True
         if dict1 is None:
